summaryrefslogtreecommitdiffstats
path: root/tdehtml/dom/dom_doc.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-27 15:54:26 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-27 15:54:26 -0600
commit7427e438358d44c37e3c8b0a9cfbb225ffd60e79 (patch)
treed977f1d23d324f23aadee0ad50acb94d7436ba80 /tdehtml/dom/dom_doc.h
parent72eecb041bf15bf64b748fc062d55f6ec860ac60 (diff)
downloadtdelibs-7427e438358d44c37e3c8b0a9cfbb225ffd60e79.tar.gz
tdelibs-7427e438358d44c37e3c8b0a9cfbb225ffd60e79.zip
Rename KHTML and kiobuffer
Diffstat (limited to 'tdehtml/dom/dom_doc.h')
-rw-r--r--tdehtml/dom/dom_doc.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/tdehtml/dom/dom_doc.h b/tdehtml/dom/dom_doc.h
index 9a5331295..cef6692c5 100644
--- a/tdehtml/dom/dom_doc.h
+++ b/tdehtml/dom/dom_doc.h
@@ -32,8 +32,8 @@
#include <dom/dom_node.h>
#include <dom/css_stylesheet.h>
-class KHTMLView;
-class KHTMLPart;
+class TDEHTMLView;
+class TDEHTMLPart;
namespace DOM {
@@ -74,7 +74,7 @@ class HTMLDocument;
* DOM Level 2 and newer provide means for creating documents directly,
* which was not possible with DOM Level 1.
*/
-class KHTML_EXPORT DOMImplementation
+class TDEHTML_EXPORT DOMImplementation
{
friend class Document;
public:
@@ -242,10 +242,10 @@ protected:
* context they were created.
*
*/
-class KHTML_EXPORT Document : public Node
+class TDEHTML_EXPORT Document : public Node
{
- friend class ::KHTMLView;
- friend class ::KHTMLPart;
+ friend class ::TDEHTMLView;
+ friend class ::TDEHTMLPart;
friend class AbstractView;
friend class DOMImplementation;
friend class HTMLFrameElement;
@@ -786,9 +786,9 @@ public:
void removeStyleSheet(const StyleSheet &sheet);
/**
* @return The KHTML view widget of this document.
*/
- KHTMLView *view() const;
+ TDEHTMLView *view() const;
/**
* Introduced in DOM Level 2
@@ -988,7 +988,7 @@ class DocumentFragmentImpl;
* \c insertBefore() and \c appendChild() .
*
*/
-class KHTML_EXPORT DocumentFragment : public Node
+class TDEHTML_EXPORT DocumentFragment : public Node
{
friend class Document;
friend class HTMLElementImpl;
@@ -1025,7 +1025,7 @@ class DOMString;
* nodes.
*
*/
-class KHTML_EXPORT DocumentType : public Node
+class TDEHTML_EXPORT DocumentType : public Node
{
friend class Document;
friend class DOMImplementation;
@@ -786,9 +786,9 @@ public:
void removeStyleSheet(const StyleSheet &sheet);
/**
- * @return The KHTML view widget of this document.
+ * @return The TDEHTML view widget of this document.
*/